Action

Enum Action 

#[non_exhaustive]
pub enum Action { Set, App, Pop, Cnt, Clr, Null, }
The default action type for option value saving, see process.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Set

Set and replace current value of AnyValue



App

Append value into AnyValue



Pop

Pop value from AnyValue



Cnt

Saving the count of arguments into AnyValue



Clr

Clear the value of AnyValue



Null

Do nothing

Implementations

Source

impl Action

pub fn is_set(&self) -> bool

pub fn is_app(&self) -> bool

pub fn is_pop(&self) -> bool

pub fn is_cnt(&self) -> bool

pub fn is_clr(&self) -> bool

pub fn is_null(&self) -> bool

pub fn store1<U>(&self, val: Option<U>, handler: &mut AnyValue) -> bool
where U: ErasedTy,

Save the value in handler.

pub fn store2<U>( &self, raw: Option<&OsStr>, val: Option<U>, raw_handler: &mut Vec<OsString>, handler: &mut AnyValue, ) -> bool
where U: ErasedTy,

Save the value in handler and raw value in raw_handler.