AOpt

Struct AOpt 

pub struct AOpt { /* private fields */ }
A multiple features option type.

Some types support by default, they all implement Infer. When create the option with creator using add_opt, the Creator will retrieve other informations from the infer type list on the table. When create the option from type using infer, the Creator will retrieve other informations from given type.

typeactionignore namestylesindexaliasdefault valuecreatorinfer type
boolAction::SetfalseStyle::Combined Style::Booleannotruefalsebbool
i32Action::AppfalseStyle::ArgumentnotrueNoneNoneNone
i64Action::AppfalseStyle::ArgumentnotrueNoneii64
u32Action::AppfalseStyle::ArgumentnotrueNoneNoneNone
u64Action::AppfalseStyle::ArgumentnotrueNoneuu64
f32Action::AppfalseStyle::ArgumentnotrueNoneNoneNone
f64Action::AppfalseStyle::ArgumentnotrueNoneff64
usizeAction::AppfalseStyle::ArgumentnotrueNoneNoneNone
isizeAction::AppfalseStyle::ArgumentnotrueNoneNoneNone
StringAction::AppfalseStyle::ArgumentnotrueNonesString
OsStringAction::AppfalseStyle::ArgumentnotrueNonerOsString
CmdAction::SetfalseStyle::CmdForward(1)truefalsecCmd
PosAction::ApptrueStyle::PosyesfalseNonepPos
MainAction::NulltrueStyle::MainAnyWherefalseNonemMain
StdinAction::SetfalseStyle::BooleanNonetrueNoneNoneStdin
StopAction::SetfalseStyle::BooleanNonetrueNoneNoneStop

For the value parser support, see RawValParser.

Implementations

Source

impl AOpt

pub fn new(name: String, type_id: TypeId, accessor: ValAccessor) -> Self

pub fn with_uid(self, uid: Uid) -> Self

Set the unique identifier of option.

pub fn with_name(self, name: impl Into<String>) -> Self

Set the name of option.

pub fn with_type(self, type: TypeId) -> Self

Set the type of option, see Ctor.

pub fn with_ignore_name(self, ignore_name: bool) -> Self

If the option will matching the name.

pub fn with_ignore_alias(self, ignore_alias: bool) -> Self

If the option will matching the alias.

pub fn with_ignore_index(self, ignore_index: bool) -> Self

If the option will matching the alias.

pub fn with_hint(self, hint: impl Into<String>) -> Self

Set the hint of option, such as --option.

pub fn with_help(self, help: impl Into<String>) -> Self

Set the help message of option.

pub fn with_action(self, action: Action) -> Self

Set the value action of option.

pub fn with_opt_help(self, help: Help) -> Self

Set the help of option.

pub fn with_style(self, styles: Vec<Style>) -> Self

Set the Style of option.

pub fn with_idx(self, index: Option<Index>) -> Self

Set the NOA index of option.

pub fn with_force(self, force: bool) -> Self

If the option is force required.

pub fn with_alias(self, alias: Option<Vec<String>>) -> Self

Set the alias of option.

pub fn with_accessor(self, value: ValAccessor) -> Self

Set the value accessor of option, it will used by Policy;

Source

impl AOpt

pub fn set_name(&mut self, name: impl Into<String>) -> &mut Self

pub fn set_type(&mut self, type: TypeId) -> &mut Self

pub fn set_value(&mut self, value: ValAccessor) -> &mut Self

pub fn set_hint(&mut self, hint: impl Into<String>) -> &mut Self

pub fn set_help(&mut self, help: impl Into<String>) -> &mut Self

pub fn set_action(&mut self, action: Action) -> &mut Self

pub fn set_style(&mut self, styles: Vec<Style>) -> &mut Self

pub fn set_index(&mut self, index: Option<Index>) -> &mut Self

pub fn set_force(&mut self, force: bool) -> &mut Self

pub fn add_alias(&mut self, name: impl Into<String>) -> &mut Self

pub fn rem_alias(&mut self, name: &str) -> &mut Self

pub fn set_ignore_name(&mut self, ignore_name: bool) -> &mut Self

pub fn set_ignore_alias(&mut self, ignore_alias: bool) -> &mut Self

pub fn set_ignore_index(&mut self, ignore_index: bool) -> &mut Self