SetCommit

Struct SetCommit 

pub struct SetCommit<'a, S, U>
where S: Set, U: Infer + 'static, U::Val: RawValParser, SetCfg<S>: ConfigValue + Default,
{ /* private fields */ }
Create option using given configurations.

Implementations

Source

impl<'a, S> SetCommit<'a, S, Placeholder>
where S: Set, SetCfg<S>: ConfigValue + Default,

pub fn new_placeholder(set: &'a mut S, info: SetCfg<S>) -> Self

pub fn set_pos_type_only<T>(self) -> SetCommit<'a, S, Pos<T>>
where T::Val: RawValParser, T: ErasedTy + Infer,

Set the infer type to Pos<T><T>.

pub fn set_pos_type<T>(self) -> SetCommit<'a, S, Pos<T>>
where T::Val: RawValParser + Clone, T: ErasedTy + Infer,

Set the infer type to Pos<T><T>, add default initializer and default storer.

The function will call add_default_initializer add add_default_storer.

pub fn set_main_type_only<T>(self) -> SetCommit<'a, S, Main<T>>
where T::Val: RawValParser, T: ErasedTy + Infer,

Set the infer type to Main<T><T>.

pub fn set_main_type<T>(self) -> SetCommit<'a, S, Main<T>>
where T::Val: RawValParser + Clone, T: ErasedTy + Infer,

Set the infer type to Main<T><T>, add default initializer and default storer.

The function will call add_default_initializer add add_default_storer.

pub fn set_any_type_only<T>(self) -> SetCommit<'a, S, AnyOpt<T>>
where T::Val: RawValParser, T: ErasedTy + Infer,

Set the infer type to AnyOpt<T><T>.

pub fn set_any_type<T>(self) -> SetCommit<'a, S, AnyOpt<T>>
where T::Val: RawValParser + Clone, T: ErasedTy + Infer,

Set the infer type to AnyOpt<T><T>, add default initializer and default storer.

The function will call add_default_initializer add add_default_storer.

Source

impl<'a, S, U> SetCommit<'a, S, U>
where S: Set, U: Infer + 'static, U::Val: RawValParser, SetCfg<S>: ConfigValue + Default,

pub fn new(set: &'a mut S, info: SetCfg<S>) -> Self

pub fn set_infer<O>(self) -> SetCommit<'a, S, O>
where O: Infer + 'static, O::Val: RawValParser,

Set the infer type of option.

pub fn run(self) -> Result<Uid, Error>

Run the commit.

It create an option using given type Ctor. And add it to referenced Set, return the new option Uid.

Source

impl<'a, S, U> SetCommit<'a, S, U>
where S: Set, U: Infer + 'static, U::Val: RawValParser, SetCfg<S>: ConfigValue + Default,

pub fn set_value_type_only<T: ErasedTy>(self) -> SetCommitWithValue<'a, S, U, T>

Set the value type of option(except for Cmd).

pub fn set_value_type<T: ErasedTy + RawValParser + Clone>( self, ) -> SetCommitWithValue<'a, S, U, T>

Set the value type of option, add default initializer and default storer.

The function will call add_default_initializer_t add add_default_storer_t.

pub fn set_validator_t<T: ErasedTy + RawValParser>( self, validator: ValValidator<T>, ) -> SetCommitWithValue<'a, S, U, T>

Set the option value validator.

pub fn set_value_t<T: ErasedTy + Clone>( self, value: T, ) -> SetCommitWithValue<'a, S, U, T>

Set the option default value.

pub fn set_values_t<T: ErasedTy + Clone>( self, value: Vec<T>, ) -> SetCommitWithValue<'a, S, U, T>

Set the option default value.

Source

impl<S, U> SetCommit<'_, S, U>
where S: Set, U: Infer + 'static, U::Val: RawValParser, SetCfg<S>: ConfigValue + Default,

pub fn set_validator(self, validator: ValValidator<U::Val>) -> Self

Set the option value validator.

pub fn add_default_storer(self) -> Self

Add default storer of type U::Val.

Source

impl<S, U> SetCommit<'_, S, U>
where S: Set, U: Infer + 'static, U::Val: Clone + RawValParser, SetCfg<S>: ConfigValue + Default,

pub fn set_value(self, value: U::Val) -> Self

Set the option default value.

pub fn set_values(self, value: Vec<U::Val>) -> Self

Set the option default value.

pub fn add_default_initializer(self) -> Self

Add a default initializer.