Structs
- AOpt
- A multiple features option type.
- AnyOpt
- Cmd
- Cmd represents a sub command flag wrapped the
booloption, it is force required in default. - Config
Builder - Config
Builder With - Constrct
Info - Parsing result of option constructor string.
- Creator
- Help
- The help information of option.
- Main
- Main are always matched; it is using for running logical before
Policyending. - MutOpt
- Simple option type wrapper, implemented
Infer. It works with the types are implementedRawValParser. - OptConfig
- Contain the information used for create option instance.
- Pos
- Pos is a position option wrapper, it is matching based on position.
- Serde
- StrParser
- Parse the option string with given prefixes, return an
ConstrctInfo.
Enums
- Action
- The default action type for option value saving, see
process. - Cid
- Index
- Index using for option match.
- Style
- Option style
Constants
Traits
- Config
Build - Config
Build Infer - Config
Build Mutable - Config
Build With - Config
Value - Deserialize
- Information
- Opt
- OptParser
- Option parser using for parsing option constructor string.
- OptValue
Ext - Serialize