Structs
A multiple features option type.
Parsing result of option constructor string.
The help information of option.
Contain the information used for create option instance.
Parse the option string with given prefixs, return an
ConstrctInfo.Initialize the value of option.
Enums
The default action type for option value saving, see
Action::process.Index using for option match.
Option style
Constants
Traits
Option parser using for parsing option constructor string.